half_permutation_fdr: Estimate the false discovery rate for the method across a...

View source: R/tune_parameter.R

half_permutation_fdrR Documentation

Estimate the false discovery rate for the method across a variety of parameters.

Description

For each parameter value, generate num.sims half-permuted datasets, and estimate the half-permutation FDR.

Usage

half_permutation_fdr(
  X,
  Y,
  alphas,
  num.sims,
  method = cbce.fast.fil,
  cov = NULL,
  fdr = "imp.pairs",
  filter = FALSE,
  timeout = Inf
)

Arguments

X, Y, cov

The original data that we intend to run the method on.

alphas

List of parameters to run the method on.

num.sims

The number of simulation to evaluate over.

method

The method to run. The method should take arguments X, Y, cov, alpha and return a collection of bi-modules.

fdr

The type of false discovery metric to use. Can be one of 'all.pairs' or 'imp.pairs'.

timeout

The maximum amount of time in seconds to let each method run, before stopping it. If set to Inf or NULL, the method will never be timed out.

Value

Returns a numeric vector of size length(alphas) that have the fdrs.


miheerdew/cbce documentation built on Aug. 28, 2023, 2:18 p.m.