View source: R/tune_parameter.R
| half_permutation_fdr | R Documentation |
For each parameter value, generate num.sims half-permuted
datasets, and estimate the half-permutation FDR.
half_permutation_fdr(
X,
Y,
alphas,
num.sims,
method = cbce.fast.fil,
cov = NULL,
fdr = "imp.pairs",
filter = FALSE,
timeout = Inf
)
X, Y, cov |
The original data that we intend to run the method on. |
alphas |
List of parameters to run the method on. |
num.sims |
The number of simulation to evaluate over. |
method |
The method to run. The method should take
arguments |
fdr |
The type of false discovery metric to use. Can be one of 'all.pairs' or 'imp.pairs'. |
timeout |
The maximum amount of time in seconds to let each method run, before stopping it. If set to Inf or NULL, the method will never be timed out. |
Returns a numeric vector of size length(alphas) that have the fdrs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.